@@ -35,10 +35,11 @@ use File::Spec;                         # from PathTools
 use IO::File;                           # from IO
 use Readonly;
 use File::pushd;                        # temporary cwd changes
+use Capture::Tiny qw(capture);
 
 Readonly our $DEFAULT_MAXRUNS => 10;
 
-our $VERSION = "0.200.3";
+our $VERSION = "0.300.0";
 
 __PACKAGE__->mk_accessors( qw( basename basedir basepath options
                                source output tmpdir format timeout stderr
@@ -215,6 +216,9 @@ sub new {
     my $texinputs_path = $options->{TEXINPUTS} || $options->{texinputs} || [];
     $texinputs_path = [ split(/:/, $texinputs_path) ] unless ref $texinputs_path;
 
+    # see http://tex.stackexchange.com/questions/149714/149865#149865
+
+    my $texinputs_sep = $OSNAME eq "MSWin32" ? ';' : ':';
 
 
     # construct and return the object
@@ -232,7 +236,7 @@ sub new {
                                  capture_stderr => $options->{capture_stderr} || 0,
                                  formatter      => $formatter,
                                  _program_path  => $path,
-                                 texinputs_path => join(':', ('.', @{$texinputs_path}, '')),
+                                 texinputs_path => join($texinputs_sep, ('.', @{$texinputs_path}, '')),
                                  preprocessors  => [],
                                  postprocessors => \@postprocessors,
                                  stats          => { runs => {} } } );
@@ -665,6 +669,7 @@ sub run_command {
 
     $envvars ||= "TEXINPUTS";
     $envvars = [ $envvars ] unless ref $envvars;
+    local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
     $self->stats->{runs}{$progname}++;
     debug("running '$program $args'") if $DEBUG;
     my $cwd = pushd($dir);
@@ -672,16 +677,22 @@ sub run_command {
     # Format the command appropriately for our O/S
 
     my $exit_status;
+    my ($stdout, $stderr);
     if ($OSNAME eq 'MSWin32') {
         $args = join(' ', @$args);
         $cmd  = "\"$program\" $args";
-        $exit_status = system($cmd);
+        ($stdout, $stderr) = capture {
+            $exit_status = system($cmd);
+        };
     }
     else {
-        local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
         $args = "'$args'" if $args =~ / \\ /mx;
-        $exit_status = system($program, @$args);
+        ($stdout, $stderr) = capture {
+            $exit_status = system($program, @$args);
+        };
     }
+    $self->{stderr} .= $stderr
+        if $self->{capture_stderr};
 
     return $exit_status;
 }
@@ -820,7 +831,7 @@ LaTeX::Driver - Latex driver
 
 =head1 VERSION
 
-This document describes version 0.200.2 of C<LaTeX::Driver>.
+This document describes version 0.200.4 of C<LaTeX::Driver>.
 
 =head1 SYNOPSIS
 
